Skip to contents

Get a pointer to an exported table from a WASM instance by name.

Usage

wasmer_get_exported_table_ext(ptr, instance_name, table_export_name)

Arguments

ptr

External pointer to WasmerRuntime.

instance_name

Name of the instance.

table_export_name

Name of the exported table.

Value

External pointer to Table, or NULL if not found

Details

Get a pointer to an exported table from a WASM instance by name

Examples

if (FALSE) { # \dontrun{
wasmer_get_exported_table_ext(ptr, "inst1", "table1")
} # }