Skip to contents

Register an R function for use as a host function in WASM (per-runtime).

Usage

wasmer_register_r_function_ext(ptr, name, fun)

Arguments

ptr

External pointer to WasmerRuntime.

fun

R function object.

_name

Name to register the function under.

Value

TRUE if successful

Details

Register an R function for use as a host function in WASM (per-runtime)

Examples

if (FALSE) { # \dontrun{
wasmer_register_r_function_ext(ptr, "myfun", function(x) x)
} # }